/// <reference types="node" />
import * as jwt from 'jsonwebtoken';
import { IAuthResponse, IConfigValues } from './interfaces';
import { IKeyIndex } from './interfaces/IKeyIndex';
/**
 * Utilities for Serverless Authentication
 */
export declare class Utils {
    /**
     * Creates redirectUrl
     * @param url {string} url base
     * @param provider {string} provider e.g. facebook
     */
    static redirectUrlBuilder(url: string, replacers: {
        provider: string;
        stage?: string;
    }): string;
    /**
     * Creates url with params
     * @param url {string} url base
     * @param params {object} url params
     */
    static urlBuilder(url: string, params: object): string;
    /**
     * Creates &amp; separated params string
     * @param params {object}
     */
    static urlParams(params: object): string;
    /**
     * Creates Json Web Token with data
     * @param data {object}
     * @param config {object} with token_secret --> change to secret
     */
    static createToken(data: string | object | Buffer, secret: jwt.Secret, options?: jwt.SignOptions): Promise<unknown>;
    /**
     * Reads Json Web Token and returns object
     * @param token {string}
     * @param config {object} with token_secret --> change to secret
     */
    static readToken(token: string, secret: string, options?: object): Promise<unknown>;
    /**
     * Creates token response and triggers callback
     * @param data {payload: object, options: object}
     * @param config: {config: IConfigValues}
     */
    static tokenResponse(data: any, config: IConfigValues): Promise<{
        url: string;
    }>;
    /**
     *
     * Creates error response and triggers callback
     * @param params
     * @param config {config: IConfigValues}
     */
    static errorResponse(params: object, config: IConfigValues): {
        url: string;
    };
    /**
     * Simple way to check for undefined value and throw error for multiple fields.
    */
    static throwUndefined: (properties: IKeyIndex, message?: string | undefined) => void;
    /**
     * Generates Policy for AWS Api Gateway custom authorize
     * @param principalId {string} data for principalId field
     * @param effect {string} 'Allow' or 'Deny'
     * @param resource {string} method arn e.g. event.methodArn
     *  (arn:aws:execute-api:<regionId>:<accountId>:<apiId>/<stage>/<method>/<resourcePath>)
     */
    static generatePolicy(principalId: string, effect: string, resource: string): IAuthResponse;
    static hasKeys(item: object): boolean;
}
